@@ -17,6 +17,6 @@
 #define FREERDP_VENDOR_STRING "FreeRDP"
 #define FREERDP_PRODUCT_STRING "FreeRDP"
 
-#define FREERDP_PROXY_PLUGINDIR "/pobj/freerdp-2.8.0/build-i386/server/proxy/plugins"
+#define FREERDP_PROXY_PLUGINDIR "/build/tmp/pobj/freerdp-2.8.1/build-amd64/server/proxy/plugins"
 
 #endif /* FREERDP_BUILD_CONFIG_H */
